@@ -1,5 +1,5 @@
 rankplot <- function(dset, trans=FALSE, label.type="item", circle.col="black", circle.bg=FALSE){
-library(graphics)
+##require(graphics)
 nitem <- ncol(dset)-1
 test <- matrix(data = 0, nrow = factorial(nitem), ncol = nitem, byrow = TRUE)
 temp1 <- 1:nitem
@@ -79,10 +79,10 @@ label[6] <- "BAC"
 
 x = c(0,1,1.5,1,0,-0.5)
 y = c(0,0,-0.866,-1.732,-1.732,-0.866)
-plot(x,y,axes=FALSE,ann=FALSE,xaxt="n",yaxt="n", xlim=c(-1.482,2.982), ylim=c(-2.232,2.232))
-symbols(x,y,circles=freq^0.5/sum(freq^0.5)/2,inches=FALSE, add=TRUE, fg=circle.col, bg=circle.bg)
-text(x,y,labels=label)
-polygon(x,y)
+graphics::plot(x,y,axes=FALSE,ann=FALSE,xaxt="n",yaxt="n", xlim=c(-1.482,2.982), ylim=c(-2.232,2.232))
+graphics::symbols(x,y,circles=freq^0.5/sum(freq^0.5)/2,inches=FALSE, add=TRUE, fg=circle.col, bg=circle.bg)
+graphics::text(x,y,labels=label)
+graphics::polygon(x,y)
 }
 
 if (nitem==4){
@@ -163,49 +163,49 @@ else {
 x <- c(1,1.66,0.55,1.98,0.77,1.53,1.27,1.88,0.44,2.56,0.64,2.15,1.15,2.38,0.76,2.72,1.24,1.98,1.61,2.23,1.26,2.55,1.51,2.2)
 y <- c(-2.33,-2.55,-1.93,-2.37,-1.70,-1.93,-2.04,-2.23,-1.22,-1.83,-0.95,-1.36,-1.43,-1.77,-1.02,-1.55,-0.4,-0.58,-1,-1.15,-0.56,-0.88,-0.24,-0.4)
 }
-symbols(x,y,circles=freq^0.5/sum(freq^0.5)/2,inches=FALSE,add=TRUE, fg=circle.col, bg=circle.bg)
-text(x,y+0.1,labels=label)
+graphics::symbols(x,y,circles=freq^0.5/sum(freq^0.5)/2,inches=FALSE,add=TRUE, fg=circle.col, bg=circle.bg)
+graphics::text(x,y+0.1,labels=label)
 
 # draw the truncated octahedron
 Ax = c(0.64,0.77,1.53,2.15,1.98,1.24)
 Ay = c(-0.95,-1.7,-1.93,-1.36,-0.58,-0.4)
-polygon(Ax,Ay)
+graphics::polygon(Ax,Ay)
 Dx = c(1.15,1.27,1.88,2.38,2.23,1.61)
 Dy = c(-1.43,-2.04,-2.23,-1.77,-1.15,-1)
-polygon(Dx,Dy,lty=3)
+graphics::polygon(Dx,Dy,lty=3)
 Ex = c(1.98,2.15,2.56,2.72,2.55,2.2)
 Ey = c(-0.58,-1.36,-1.83,-1.55,-0.88,-0.4)
-polygon(Ex,Ey)
+graphics::polygon(Ex,Ey)
 Fx = c(0.55,1,1.66,1.98,1.53,0.77)
 Fy = c(-1.93,-2.33,-2.55,-2.37,-1.93,-1.7)
-polygon(Fx,Fy)
+graphics::polygon(Fx,Fy)
 Gx = c(1.66,1.98,2.56,2.72)
 Gy = c(-2.55,-2.37,-1.83,-1.55)
-lines(Gx,Gy)
+graphics::lines(Gx,Gy)
 Hx = c(0.55,0.44,0.64,1.24,1.51,2.2)
 Hy = c(-1.93,-1.22,-0.95,-0.4,-0.24,-0.4)
-lines(Hx,Hy)
+graphics::lines(Hx,Hy)
 Ix = c(0.44,0.76,1.26,1.51)
 Iy = c(-1.22,-1.02,-0.56,-0.24)
-lines(Ix,Iy,lty=3)
+graphics::lines(Ix,Iy,lty=3)
 Jx = c(1.26,1.61)
 Jy = c(-0.56,-1)
-lines(Jx,Jy,lty=3)
+graphics::lines(Jx,Jy,lty=3)
 Kx = c(0.76,1.15)
 Ky = c(-1.02,-1.43)
-lines(Kx,Ky,lty=3)
+graphics::lines(Kx,Ky,lty=3)
 Lx = c(1,1.27)
 Ly = c(-2.33,-2.04)
-lines(Lx,Ly,lty=3)
+graphics::lines(Lx,Ly,lty=3)
 Mx = c(1.66,1.88)
 My = c(-2.55,-2.23)
-lines(Mx,My,lty=3)
+graphics::lines(Mx,My,lty=3)
 Nx = c(2.23,2.55)
 Ny = c(-1.15,-0.88)
-lines(Nx,Ny,lty=3)
+graphics::lines(Nx,Ny,lty=3)
 Ox = c(2.38,2.72)
 Oy = c(-1.77,-1.55)
-lines(Ox,Oy,lty=3)
+graphics::lines(Ox,Oy,lty=3)
 
 }
 
